//+------------------------------------------------------------------+
//|                                                  BB Breakout.mq4 |
//|                                                           Marvin |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Marvin"
#property link      "https://www.mql5.com"
#property version   "1.00"
#property strict

//--- indicator settings
#property indicator_chart_window
#property indicator_buffers 2

#property indicator_type1 DRAW_ARROW
#property indicator_width1 3
#property indicator_color1 0x11FF00
#property indicator_label1 "Call"

#property indicator_type2 DRAW_ARROW
#property indicator_width2 3
#property indicator_color2 0x0000FF
#property indicator_label2 "Put"

//--- indicator buffers
double Buffer1[];
double Buffer2[];

extern bool AlertON = true;
datetime time_alert; //used when sending alert
bool Audible_Alerts = true;
double myPoint; //initialized in OnInit

void myAlert(string type, string message)
  {
   if(type == "print")
      Print(message);
   else if(type == "error")
     {
      Print(type+" | BB Breakout @ "+Symbol()+","+Period()+" | "+message);
     }
   else if(type == "order")
     {
     }
   else if(type == "modify")
     {
     }
   else if(type == "indicator")
     {
      if(Audible_Alerts) Alert(type+" | BB Breakout @ "+Symbol()+","+Period()+" | "+message);
     }
  }

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {   
   IndicatorBuffers(2);
   SetIndexBuffer(0, Buffer1);
   SetIndexEmptyValue(0, 0);
   SetIndexArrow(0, 241);
   SetIndexBuffer(1, Buffer2);
   SetIndexEmptyValue(1, 0);
   SetIndexArrow(1, 242);
   //initialize myPoint
   myPoint = Point();
   if(Digits() == 5 || Digits() == 3)
     {
      myPoint *= 10;
     }
   Audible_Alerts = AlertON; //initialize to input
   return(INIT_SUCCEEDED);
  }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime& time[],
                const double& open[],
                const double& high[],
                const double& low[],
                const double& close[],
                const long& tick_volume[],
                const long& volume[],
                const int& spread[])
  {
   int limit = rates_total - prev_calculated;
   //--- counting from 0 to rates_total
   ArraySetAsSeries(Buffer1, true);
   ArraySetAsSeries(Buffer2, true);
   //--- initial zero
   if(prev_calculated < 1)
     {
      ArrayInitialize(Buffer1, 0);
      ArrayInitialize(Buffer2, 0);
     }
   else
      limit++;
   
   //--- main loop
   for(int i = limit-1; i >= 0; i--)
     {
      if (i >= MathMin(5000-1, rates_total-1-50)) continue; //omit some old rates to prevent "Array out of range" or slow calculation   
      //Indicator Buffer 1
      if(Low[i] < iBands(NULL, PERIOD_CURRENT, 14, 5, 0, PRICE_CLOSE, MODE_LOWER, i) //Candlestick Low < Bollinger Bands
      )
        {
         Buffer1[i] = Low[i] - 0.5 * myPoint; //Set indicator value at Candlestick Low - fixed value
         if(i == 0 && Time[0] != time_alert) { myAlert("indicator", "Call"); time_alert = Time[0]; } //Instant alert, only once per bar
        }
      else
        {
         Buffer1[i] = 0;
        }
      //Indicator Buffer 2
      if(High[i] > iBands(NULL, PERIOD_CURRENT, 14, 5, 0, PRICE_CLOSE, MODE_UPPER, i) //Candlestick High > Bollinger Bands
      )
        {
         Buffer2[i] = High[i] + 0.5 * myPoint; //Set indicator value at Candlestick High + fixed value
         if(i == 0 && Time[0] != time_alert) { myAlert("indicator", "Put"); time_alert = Time[0]; } //Instant alert, only once per bar
        }
      else
        {
         Buffer2[i] = 0;
        }
     }
   return(rates_total);
  }
//+------------------------------------------------------------------+